CountryPickerWidget class

Inheritance

Constructors

CountryPickerWidget({Key? key, ValueChanged<Country>? onSelected, TextStyle itemTextStyle = _defaultItemTextStyle, TextStyle searchInputStyle = _defaultSearchInputStyle, InputDecoration? searchInputDecoration, String searchHintText = _kDefaultSearchHintText, double flagIconSize = 32, bool showSeparator = false, bool focusSearchBox = false})
const

Properties

flagIconSize → double
Flag icon size (width). Default set to 32.
final
focusSearchBox → bool
Can be set to true for opening the keyboard automatically. Default set to false
final
hashCode → int
The hash code for this object.
no setterinherited
itemTextStyle → TextStyle
itemTextStyle can be used to change the TextStyle of the Text in ListItem. Default is _defaultItemTextStyle
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onSelected → ValueChanged<Country>?
This callback will be called on selection of a Country.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
searchHintText → String
This will change the hint of the search box. Alternatively searchInputDecoration can be used to change decoration fully.
final
searchInputDecoration → InputDecoration?
searchInputDecoration can be used to change the decoration for SearchBox.
final
searchInputStyle → TextStyle
searchInputStyle can be used to change the TextStyle of the Text in SearchBox. Default is searchInputStyle
final
showSeparator → bool
Can be set to true for showing the List Separator. Default set to false
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _CountryPickerWidgetState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited